# Python Library Template

See documentation: https://bjarne.gitlab.bjarnessen.no/pysquic

See changelog: https://bjarne.gitlab.bjarnessen.no/pysquid/changelog

To upload to PYPI, run manual stage with CI variables: TWINE_PASSWORD and TWINE_USERNAME